@@ -1,6 +1,6 @@
 #encoding:utf-8
 
-from Bf import gorun
+from Bigforest.Bf import gorun
 import time
 import socket
 import threading
